==> drumgizmo_0.9.11.orig.tar.gz: drumgizmo-0.9.11/src/latencyfilter.cc <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            latencyfilter.cc
 *
 *  Fri Jun 10 22:42:53 CEST 2016
 *  Copyright 2016 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include "latencyfilter.h"

LatencyFilter::LatencyFilter(Settings& settings)
	: settings(settings)
{
}

bool LatencyFilter::filter(event_t& events, size_t pos)
{
	return true;
}

std::size_t LatencyFilter::getLatency() const
{
	// TODO: If enabled in settings, return the maximum number of samples
	// with which the latency filter can move notes forward.
	return 0;
}

==> drumgizmo_0.9.14.orig.tar.gz: drumgizmo-0.9.14/src/latencyfilter.cc <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            latencyfilter.cc
 *
 *  Fri Jun 10 22:42:53 CEST 2016
 *  Copyright 2016 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include "latencyfilter.h"

LatencyFilter::LatencyFilter(Settings& settings)
	//: settings(settings)
{
}

bool LatencyFilter::filter(event_t& events, size_t pos)
{
	return true;
}

std::size_t LatencyFilter::getLatency() const
{
	// TODO: If enabled in settings, return the maximum number of samples
	// with which the latency filter can move notes forward.
	return 0;
}
